@@ -1,21 +1,11 @@
 from gevent import spawn, spawn_later
 from gevent_zeromq import zmq
 
-try:
-    from gevent_utils import BlockingDetector
-    spawn(BlockingDetector())
-except ImportError:
-    pass
-
 # server
 ctx = zmq.Context()
 sock = ctx.socket(zmq.PUSH)
 sock.bind('ipc:///tmp/zmqtest')
 
-print type(sock)
-print sock.recv
-print sock.send
-
 spawn(sock.send_pyobj, ('this', 'is', 'a', 'python', 'tuple'))
 spawn_later(1, sock.send_pyobj, {'hi': 1234})
 spawn_later(2, sock.send_pyobj, ({'this': ['is a more complicated object', ':)']}, 42, 42, 42))
